Supported Ports
==============================

CircuitPython supports a number of microcontroller families. Support quality for each varies
depending on the active contributors for each port.

Adafruit sponsored developers are actively contributing to atmel-samd, mimxrt10xx, nrf and stm
ports. They also maintain the other ports in order to ensure the boards build. Additional testing
is limited.

.. toctree::
    :maxdepth: 2

    ../ports/atmel-samd/README
    ../ports/cxd56/README
    ../ports/esp32s2/README
    ../ports/litex/README
    ../ports/mimxrt10xx/README
    ../ports/nrf/README
    ../ports/raspberrypi/README
    ../ports/stm/README
